@@ -1,4 +1,4 @@
-from Datasets.DatasetSpecs.MPII.MPIIDatasetSpecs import MPII
+from cv_pose.DatasetSpecs.MPII.MPIIDatasetSpecs import MPII
 
 class ClimbingSplit(MPII):
     def generate_csv(self):
